# Changelog

## 0.0.1-alpha.1 (2025-05-14)

Full Changelog: [v0.0.1-alpha.0...v0.0.1-alpha.1](https://github.com/octogen-systems/octogen-py-api/compare/v0.0.1-alpha.0...v0.0.1-alpha.1)

### Chores

* update SDK settings ([b062541](https://github.com/octogen-systems/octogen-py-api/commit/b062541cd48785c811d7917c785f8ecdff069fa9))
* update SDK settings ([5220f36](https://github.com/octogen-systems/octogen-py-api/commit/5220f3690b3054ac5a3bf8343e8f3f8797c89437))
